@@ -4,10 +4,12 @@ import warnings
 import numpy as np
 from numpy.lib.stride_tricks import as_strided
 from scipy._lib._util import _apply_over_batch
+from scipy._lib._array_api import array_namespace, xp_capabilities, xp_size
+import scipy._lib.array_api_extra as xpx
 
 
 __all__ = ['toeplitz', 'circulant', 'hankel',
-           'hadamard', 'leslie', 'kron', 'block_diag', 'companion',
+           'hadamard', 'leslie', 'block_diag', 'companion',
            'helmert', 'hilbert', 'invhilbert', 'pascal', 'invpascal', 'dft',
            'fiedler', 'fiedler_companion', 'convolution_matrix']
 
@@ -25,6 +27,11 @@ def toeplitz(c, r=None):
     and r as its first row. If r is not given, ``r == conjugate(c)`` is
     assumed.
 
+    The documentation is written assuming array arguments are of specified
+    "core" shapes. However, array argument(s) of this function may have additional
+    "batch" dimensions prepended to the core shape. In this case, the array is treated
+    as a batch of lower-dimensional slices; see :ref:`linalg_batch` for details.
+
     Parameters
     ----------
     c : array_like
@@ -35,12 +42,6 @@ def toeplitz(c, r=None):
         r[0] is ignored; the first row of the returned matrix is
         ``[c[0], r[1:]]``.
 
-        .. warning::
-
-            Beginning in SciPy 1.17, multidimensional input will be treated as a batch,
-            not ``ravel``\ ed. To preserve the existing behavior, ``ravel`` arguments
-            before passing them to `toeplitz`.
-
     Returns
     -------
     A : (len(c), len(r)) ndarray
@@ -71,19 +72,16 @@ def toeplitz(c, r=None):
            [ 4.-1.j,  2.+3.j,  1.+0.j]])
 
     """
-    c = np.asarray(c)
+    c = np.atleast_1d(c)
     if r is None:
         r = c.conjugate()
     else:
-        r = np.asarray(r)
+        r = np.atleast_1d(r)
+    return _toeplitz(c, r)
 
-    if c.ndim > 1 or r.ndim > 1:
-        msg = ("Beginning in SciPy 1.17, multidimensional input will be treated as a "
-               "batch, not `ravel`ed. To preserve the existing behavior and silence "
-               "this warning, `ravel` arguments before passing them to `toeplitz`.")
-        warnings.warn(msg, FutureWarning, stacklevel=2)
 
-    c, r = c.ravel(), r.ravel()
+@_apply_over_batch(("c", 1), ("r", 1))
+def _toeplitz(c, r):
     # Form a 1-D array containing a reversed c followed by r[1:] that could be
     # strided to give us toeplitz matrix.
     vals = np.concatenate((c[::-1], r[1:]))
@@ -96,6 +94,10 @@ def circulant(c):
     """
     Construct a circulant matrix.
 
+    Array argument(s) of this function may have additional
+    "batch" dimensions prepended to the core shape. In this case, the array is treated
+    as a batch of lower-dimensional slices; see :ref:`linalg_batch` for details.
+
     Parameters
     ----------
     c : (..., N,)  array_like
@@ -154,7 +156,7 @@ def circulant(c):
 
 
 def hankel(c, r=None):
-    """
+    r"""
     Construct a Hankel matrix.
 
     The Hankel matrix has constant anti-diagonals, with `c` as its
@@ -167,13 +169,17 @@ def hankel(c, r=None):
     Parameters
     ----------
     c : array_like
-        First column of the matrix. Whatever the actual shape of `c`, it
-        will be converted to a 1-D array.
+        First column of the matrix.
     r : array_like, optional
         Last row of the matrix. If None, ``r = zeros_like(c)`` is assumed.
         r[0] is ignored; the last row of the returned matrix is
-        ``[c[-1], r[1:]]``. Whatever the actual shape of `r`, it will be
-        converted to a 1-D array.
+        ``[c[-1], r[1:]]``.
+
+        .. warning::
+
+            Beginning in SciPy 1.19, multidimensional input will be treated as a batch,
+            not ``ravel``\ ed. To preserve the existing behavior, ``ravel`` arguments
+            before passing them to `toeplitz`.
 
     Returns
     -------
@@ -199,11 +205,19 @@ def hankel(c, r=None):
            [4, 7, 7, 8, 9]])
 
     """
-    c = np.asarray(c).ravel()
+    c = np.asarray(c)
     if r is None:
         r = np.zeros_like(c)
     else:
-        r = np.asarray(r).ravel()
+        r = np.asarray(r)
+
+    if c.ndim > 1 or r.ndim > 1:
+        msg = ("Beginning in SciPy 1.19, multidimensional input will be treated as a "
+               "batch, not `ravel`ed. To preserve the existing behavior and silence "
+               "this warning, `ravel` arguments before passing them to `hankel`.")
+        warnings.warn(msg, FutureWarning, stacklevel=2)
+        c, r = c.ravel(), r.ravel()
+
     # Form a 1-D array of values to be used in the matrix, containing `c`
     # followed by r[1:].
     vals = np.concatenate((c, r[1:]))
@@ -279,6 +293,11 @@ def leslie(f, s):
     n-1 array of survival coefficients `s`, return the associated Leslie
     matrix.
 
+    The documentation is written assuming array arguments are of specified
+    "core" shapes. However, array argument(s) of this function may have additional
+    "batch" dimensions prepended to the core shape. In this case, the array is treated
+    as a batch of lower-dimensional slices; see :ref:`linalg_batch` for details.
+
     Parameters
     ----------
     f : (N,) array_like
@@ -339,60 +358,7 @@ def leslie(f, s):
     return a
 
 
-def kron(a, b):
-    """
-    Kronecker product.
-
-    .. deprecated:: 1.15.0
-        `kron` has been deprecated in favour of `numpy.kron` and will be
-        removed in SciPy 1.17.0.
-
-    The result is the block matrix::
-
-        a[0,0]*b    a[0,1]*b  ... a[0,-1]*b
-        a[1,0]*b    a[1,1]*b  ... a[1,-1]*b
-        ...
-        a[-1,0]*b   a[-1,1]*b ... a[-1,-1]*b
-
-    Parameters
-    ----------
-    a : (M, N) ndarray
-        Input array
-    b : (P, Q) ndarray
-        Input array
-
-    Returns
-    -------
-    A : (M*P, N*Q) ndarray
-        Kronecker product of `a` and `b`.
-
-    Examples
-    --------
-    >>> from numpy import array
-    >>> from scipy.linalg import kron
-    >>> kron(array([[1,2],[3,4]]), array([[1,1,1]]))
-    array([[1, 1, 1, 2, 2, 2],
-           [3, 3, 3, 4, 4, 4]])
-
-    """
-    msg = ("`kron` has been deprecated in favour of `numpy.kron` in SciPy"
-           " 1.15.0 and will be removed in SciPy 1.17.0.")
-    warnings.warn(msg, DeprecationWarning, stacklevel=2)
-    # accommodate empty arrays
-    if a.size == 0 or b.size == 0:
-        m = a.shape[0] * b.shape[0]
-        n = a.shape[1] * b.shape[1]
-        return np.empty_like(a, shape=(m, n))
-
-    if not a.flags['CONTIGUOUS']:
-        a = np.reshape(a, a.shape)
-    if not b.flags['CONTIGUOUS']:
-        b = np.reshape(b, b.shape)
-    o = np.outer(a, b)
-    o = o.reshape(a.shape + b.shape)
-    return np.concatenate(np.concatenate(o, axis=1), axis=1)
-
-
+@xp_capabilities(jax_jit=False, allow_dask_compute=2)
 def block_diag(*arrs):
     """
     Create a block diagonal array from provided arrays.
@@ -404,12 +370,16 @@ def block_diag(*arrs):
          [0, B, 0],
          [0, 0, C]]
 
+    The documentation is written assuming array arguments are of specified
+    "core" shapes. However, array argument(s) of this function may have additional
+    "batch" dimensions prepended to the core shape. In this case, the array is treated
+    as a batch of lower-dimensional slices; see :ref:`linalg_batch` for details.
+
     Parameters
     ----------
     A, B, C, ... : array_like
         Input arrays.  A 1-D array or array_like sequence of length ``n`` is
-        treated as a 2-D array with shape ``(1, n)``. Any dimensions before
-        the last two are treated as batch dimensions; see :ref:`linalg_batch`.
+        treated as a 2-D array with shape ``(1, n)``.
 
     Returns
     -------
@@ -458,20 +428,24 @@ def block_diag(*arrs):
            [ 0.,  0.,  0.,  6.,  7.]])
 
     """
+    xp = array_namespace(*arrs)
+
     if arrs == ():
         arrs = ([],)
-    arrs = [np.atleast_2d(a) for a in arrs]
+    arrs = [xpx.atleast_nd(xp.asarray(a), ndim=2) for a in arrs]
 
     batch_shapes = [a.shape[:-2] for a in arrs]
     batch_shape = np.broadcast_shapes(*batch_shapes)
-    arrs = [np.broadcast_to(a, batch_shape + a.shape[-2:]) for a in arrs]
-    out_dtype = np.result_type(*[arr.dtype for arr in arrs])
-    block_shapes = np.array([a.shape[-2:] for a in arrs])
-    out = np.zeros(batch_shape + tuple(np.sum(block_shapes, axis=0)), dtype=out_dtype)
+    arrs = [xp.broadcast_to(a, batch_shape + a.shape[-2:]) for a in arrs]
+    out_dtype = xp.result_type(*arrs)
+    block_shapes = [a.shape[-2:] for a in arrs]
+    out = xp.zeros(batch_shape +
+                   tuple(map(int, xp.sum(xp.asarray(block_shapes), axis=0))),
+                   dtype=out_dtype)
 
     r, c = 0, 0
     for i, (rr, cc) in enumerate(block_shapes):
-        out[..., r:r + rr, c:c + cc] = arrs[i]
+        out = xpx.at(out)[..., r:r+rr, c:c+cc].set(arrs[i])
         r += rr
         c += cc
     return out
@@ -484,6 +458,10 @@ def companion(a):
     Create the companion matrix [1]_ associated with the polynomial whose
     coefficients are given in `a`.
 
+    Array argument(s) of this function may have additional
+    "batch" dimensions prepended to the core shape. In this case, the array is treated
+    as a batch of lower-dimensional slices; see :ref:`linalg_batch` for details.
+
     Parameters
     ----------
     a : (..., N) array_like
@@ -969,6 +947,7 @@ def dft(n, scale=None):
     return m
 
 
+@xp_capabilities()
 def fiedler(a):
     """Returns a symmetric Fiedler matrix
 
@@ -978,6 +957,10 @@ def fiedler(a):
     eigenvalues are negative. Although not valid generally, for certain inputs,
     the inverse and the determinant can be derived explicitly as given in [1]_.
 
+    Array argument(s) of this function may have additional
+    "batch" dimensions prepended to the core shape. In this case, the array is treated
+    as a batch of lower-dimensional slices; see :ref:`linalg_batch` for details.
+
     Parameters
     ----------
     a : (..., n,) array_like
@@ -1037,17 +1020,15 @@ def fiedler(a):
     15409152
 
     """
-    a = np.atleast_1d(a)
+    xp = array_namespace(a)
+    a = xpx.atleast_nd(xp.asarray(a), ndim=1)
 
-    if a.ndim > 1:
-        return np.apply_along_axis(fiedler, -1, a)
-
-    if a.size == 0:
-        return np.array([], dtype=float)
-    elif a.size == 1:
-        return np.array([[0.]])
+    if xp_size(a) == 0:
+        return xp.asarray([], dtype=xp.float64)
+    elif xp_size(a) == 1:
+        return xp.asarray([[0.]])
     else:
-        return np.abs(a[:, None] - a)
+        return xp.abs(a[..., :, xp.newaxis] - a[..., xp.newaxis, :])
 
 
 def fiedler_companion(a):
@@ -1057,6 +1038,10 @@ def fiedler_companion(a):
     pentadiagonal matrix with a special structure whose eigenvalues coincides
     with the roots of ``a``.
 
+    Array argument(s) of this function may have additional
+    "batch" dimensions prepended to the core shape. In this case, the array is treated
+    as a batch of lower-dimensional slices; see :ref:`linalg_batch` for details.
+
     Parameters
     ----------
     a : (..., N) array_like
@@ -1140,6 +1125,10 @@ def convolution_matrix(a, n, mode='full'):
     Constructs the Toeplitz matrix representing one-dimensional
     convolution [1]_.  See the notes below for details.
 
+    Array argument(s) of this function may have additional
+    "batch" dimensions prepended to the core shape. In this case, the array is treated
+    as a batch of lower-dimensional slices; see :ref:`linalg_batch` for details.
+
     Parameters
     ----------
     a : (..., m) array_like
