@@ -867,7 +867,10 @@ All functions
 #
 
 import numpy as np
-from .blas import _get_funcs, _memoize_get_funcs
+from .blas import (
+    _get_funcs, _memoize_get_funcs,
+    find_best_blas_type as find_best_lapack_type   # to appease the name test
+)
 from scipy.linalg import _flapack
 from re import compile as regex_compile
 try:
@@ -1089,12 +1092,22 @@ def _check_work_float(value, dtype, int_dtype):
 # compatible types, i.e., 'float32, float64, complex64, complex128'.
 # Then it can be checked via "casting_dict[arr.dtype.char]"
 
+# TODO unify "normalization" functions below, see gh-24505
+
 _lapack_cast_dict = {x: ''.join([y for y in 'fdFD' if np.can_cast(x, y)])
                     for x in np.typecodes['All']}
 
 def _normalize_lapack_dtype(a, overwrite_a):
     """Make sure an input array has a LAPACK-compatible dtype, cast and copy otherwise.
     """
+    _, dtyp, _ = find_best_lapack_type((a,))
+    needs_copy = dtyp.char != a.dtype.char  # .char to tell 'g' from 'd' on arm
+    if needs_copy:
+        a = a.astype(dtyp)   # makes a copy, free to scratch
+    return a, overwrite_a or needs_copy
+
+
+def _normalize_lapack_dtype1(a, overwrite_a):
     if a.dtype.char not in 'fdFD':
         dtype_char = _lapack_cast_dict[a.dtype.char]
         if not dtype_char:  # No casting possible
