@@ -1135,7 +1135,7 @@ class TestHyp2f1:
                     c=8.5,
                     z=(0.7368421052631575+0.5263157894736841j),
                     expected=(6.468457061368628+24.190040684917374j),
-                    rtol=5e-16,
+                    rtol=6e-16,
                 ),
             ),
             pytest.param(
@@ -1662,7 +1662,7 @@ class TestHyp2f1:
                     c=4.0013768449590685,
                     z=(0.3413793103448277-0.8724137931034484j),
                     expected=(0.2722302180888523-0.21790187837266162j),
-                    rtol=1e-12,
+                    rtol=1.2e-12,
                 ),
             ),
             pytest.param(
