@@ -1,4 +1,5 @@
 from functools import cached_property
+from types import GenericAlias
 
 import numpy as np
 from scipy import linalg
@@ -56,6 +57,10 @@ class Covariance:
     4.9595685102808205e-08
 
     """
+
+    # generic type compatibility with scipy-stubs
+    __class_getitem__ = classmethod(GenericAlias)
+
     def __init__(self):
         message = ("The `Covariance` class cannot be instantiated directly. "
                    "Please use one of the factory methods "
@@ -462,6 +467,8 @@ class Covariance:
 
 class CovViaPrecision(Covariance):
 
+    __class_getitem__ = None
+
     def __init__(self, precision, covariance=None):
         precision = self._validate_matrix(precision, 'precision')
         if covariance is not None:
@@ -537,6 +544,8 @@ class CovViaDiagonal(Covariance):
 
 class CovViaCholesky(Covariance):
 
+    __class_getitem__ = None
+
     def __init__(self, cholesky):
         L = self._validate_matrix(cholesky, 'cholesky')
 
@@ -561,6 +570,8 @@ class CovViaCholesky(Covariance):
 
 class CovViaEigendecomposition(Covariance):
 
+    __class_getitem__ = None
+
     def __init__(self, eigendecomposition):
         eigenvalues, eigenvectors = eigendecomposition
         eigenvalues = self._validate_vector(eigenvalues, 'eigenvalues')
@@ -620,6 +631,8 @@ class CovViaPSD(Covariance):
     Representation of a covariance provided via an instance of _PSD
     """
 
+    __class_getitem__ = None
+
     def __init__(self, psd):
         self._LP = psd.U
         self._log_pdet = psd.log_pdet
